Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/MHSanaei/3x-ui.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorsomebodywashere <68244480+somebodywashere@users.noreply.github.com>2023-08-01 23:58:16 +0300
committerGitHub <noreply@github.com>2023-08-01 23:58:16 +0300
commitdd0217b46b7a557c52a7f8a19b08530cb2878219 (patch)
tree9efa21dea60259b3e19b769873c9a6d0fd5495a2 /web/web.go
parentb805bf62229ef4a1211b6bc1e7603c07b12b9653 (diff)
IP Limit Tweaks to reduce false bans (#850)
* IP Limit Tweaks to reduce false bans 1) Check IPs every 10s instead of 20s 2) F2B jail: maxretry 3 -> 4, findtime 100 -> 60 * USERS SHOULD UPDATE BANTIME ONCE AFTER UPDATE to recreate jail for Ip Limit
Diffstat (limited to 'web/web.go')
-rw-r--r--web/web.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/web/web.go b/web/web.go
index 14e06f67..9cde6a6c 100644
--- a/web/web.go
+++ b/web/web.go
@@ -250,8 +250,8 @@ func (s *Server) startTask() {
// Check the inbound traffic every 30 seconds that the traffic exceeds and expires
s.cron.AddJob("@every 30s", job.NewCheckInboundJob())
- // check client ips from log file every 20 sec
- s.cron.AddJob("@every 20s", job.NewCheckClientIpJob())
+ // check client ips from log file every 10 sec
+ s.cron.AddJob("@every 10s", job.NewCheckClientIpJob())
// check client ips from log file every 3 day
s.cron.AddJob("@every 3d", job.NewClearLogsJob())